package com.gic.cloud.data.hook.service.deal.queryfilter;

import com.gic.api.base.commons.Page;
import com.gic.cloud.data.hook.api.dto.FilterQueryDataDTO;
import com.gic.cloud.data.hook.api.enums.QueryFilterCodeEnum;
import com.gic.cloud.data.hook.service.deal.BaseQueryFilter;
import com.gic.cloud.data.hook.service.deal.QueryFilterContext;
import com.gic.cloud.data.hook.service.entity.QueryFilterInfo;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.dto.StoreSearchDTO;
import com.gic.enterprise.api.service.StoreService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class StoreNameQueryFilter implements BaseQueryFilter {

    @Autowired
    private StoreService storeService;

    @Override
    public boolean checkFilter(QueryFilterContext context) {
        QueryFilterInfo queryFilterInfo = context.getQueryFilterInfo();
        if (null == queryFilterInfo||queryFilterInfo.getFilterCode()==null) {
            return false;
        }
        return queryFilterInfo.getFilterCode().equals(QueryFilterCodeEnum.STORE_NAME.getCode());
    }

    @Override
    public Page<FilterQueryDataDTO> pageQueryData(QueryFilterContext context) {
        Page<StoreDTO> page = new Page<>();
        page.setPageSize(context.getPageSize());
        page.setCurrentPage(context.getPageNum());

        StoreSearchDTO storeSearchDTO = new StoreSearchDTO();
        storeSearchDTO.setEnterpriseId(context.getEnterpriseId());
        storeSearchDTO.setSearchName(context.getSearch());
        storeSearchDTO.setStatusIn("-3");
        Page retPage = storeService.storeListPage(page, storeSearchDTO);
        Page<StoreDTO> storeDTOPage = PageHelperUtils.changePageToCurrentPage(retPage, StoreDTO.class);

//        Page<ClerkDTO> clerkDTOPage = clerkService.pageUserBySearchName(context.getEnterpriseId(), context.getSearch(), context.getPageNum(), context.getPageSize());
        Page<FilterQueryDataDTO> ret =new Page<>();
        ret.setPageSize(context.getPageSize());
        ret.setCurrentPage(context.getPageNum());
        ret.setTotalCount(storeDTOPage.getTotalCount());
        List<StoreDTO> result = storeDTOPage.getResult();
        if (CollectionUtils.isEmpty(result)) {
            return ret;
        }
        List<FilterQueryDataDTO> retList = result.stream().map(mid -> {
            FilterQueryDataDTO filterQueryDataDTO = new FilterQueryDataDTO();
            filterQueryDataDTO.setShowName(mid.getStoreName());
            filterQueryDataDTO.setItemValue(mid.getStoreName());
            filterQueryDataDTO.setSubShowName(mid.getStoreCode());
            filterQueryDataDTO.setItemId(mid.getStoreId());
            return filterQueryDataDTO;
        }).collect(Collectors.toList());
        ret.setResult(retList);
        return ret;
    }

    @Override
    public List<FilterQueryDataDTO> listBackByItems(QueryFilterContext context) {
        List<StoreDTO> storeDTOS = storeService.queryStore(context.getItems());
        List<FilterQueryDataDTO> retList = storeDTOS.stream().map(mid -> {
            FilterQueryDataDTO filterQueryDataDTO = new FilterQueryDataDTO();
            filterQueryDataDTO.setShowName(mid.getStoreCode());
            filterQueryDataDTO.setItemValue(mid.getStoreCode());
            filterQueryDataDTO.setSubShowName(mid.getStoreName());
            filterQueryDataDTO.setItemId(mid.getStoreId());
            return filterQueryDataDTO;
        }).collect(Collectors.toList());
        return retList;
    }
}
